# **********************************************************************
# Copyright 2017 VMware, Inc.  All rights reserved. VMware Confidential.
# **********************************************************************
# $Id$
# $DateTime$
# $Change$
# $Author$
# **********************************************************************
import json

from cli.commands.cli_command_provider import CliCommandProvider
from cli.commands.lcp_common.opsagent.client import get_opsagent_cli_output
from cli.commands.lcp_common.opsagent.client import load_response_output


class GetOpsAgentLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_opsagent_cli_output("get/loglevel")
        if response is None:
            return "MSG_OPSAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class SetOpsAgentLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        log_level = cmd_list[4]
        response = get_opsagent_cli_output("set/loglevel", [log_level])
        if response is None:
            return "MSG_OPSAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class GetOpsAgentWFTTraceLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_opsagent_cli_output("get/lib-wft/tracelevel")
        if response is None:
            return "MSG_OPSAGENT_TRACE_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class SetOpsAgentWFTTraceLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        wft_level = cmd_list[5]
        response = get_opsagent_cli_output("set/lib-wft/tracelevel", [wft_level])
        if response is None:
            return "MSG_OPSAGENT_TRACE_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class GetOpsAgentWFTLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_opsagent_cli_output("get/lib-wft/loglevel")
        if response is None:
            return "MSG_OPSAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class SetOpsAgentWFTLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        wft_level = cmd_list[5]
        response = get_opsagent_cli_output("set/lib-wft/loglevel", [wft_level])
        if response is None:
            return "MSG_OPSAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class GetMpaClientStatus(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_opsagent_cli_output("get/mpaclient")
        output = load_response_output(response)
        if output is None:
            return "MSG_OPSAGENT_MPACLIENT_STATUS_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class ResetTransportNode(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_opsagent_cli_output("nsxa/reset")
        if response is None:
            return "MSG_OPSAGENT_NSXA_RESET_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class NsxaReloadOptions(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_opsagent_cli_output("nsxa/reload_options")
        if response is None:
            return "MSG_OPSAGENT_NSXA_RELOAD_CFG_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class GetOpsAgentShaClientLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_opsagent_cli_output("get/lib-sha/loglevel")
        if response is None:
            return "MSG_OPSAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class SetOpsAgentShaClientLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        level = cmd_list[5]
        response = get_opsagent_cli_output("set/lib-sha/loglevel", [level])
        if response is None:
            return "MSG_OPSAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)
