# Copyright 2013 - 2017  VMware, Inc.  All rights reserved.
# Hey Emacs, -*- mode: Python; coding: utf-8 -*-
# **********************************************************
#
"""
Implementation of appliance SNMP API.  This module handles
communications with snmpd over Unix Domain socket
"""

__author__ = "VMware, Inc."

import logging
import socket
import time

logger = logging.getLogger(__name__)

ctrl_path = '/var/run/snmp.ctl'

def _connect():
    '''return socket to vmware-snmp diagnostic interface '''
    connected = False
    msg = "n/a"
    sck = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
    retries = 3
    #  transient failures can and will occur in: getaddrinfo, connect so repeat
    while retries > 0:
        retries -= 1
        try:
            sck.connect(ctrl_path)
            connected = True
            break
        except Exception as err:
            time.sleep(3)
            msg = str(err)
            logger.error("Contact snmpd failed, '%s' err: %s" % (ctrl_path, msg))

    if sck is None or not connected:
        try:
            sck.close()
        except Exception:
            pass
        raise Exception("Connect to control port failed, reason %s" % msg)
    return sck

def _send_cmd(sck, cmd):
    '''write all bytes in cmd to sck then close it else throw exception'''
    totalsent = 0
    while totalsent < len(cmd):
        sent = sck.send(cmd[totalsent:])
        if sent == 0:
            logger.error("_send_cmd: unable to transmit command %s" % cmd)
            raise Exception("_send_cmd: unable to transmit command %s" % cmd)
        totalsent = totalsent + sent
        logger.debug("_send_cmd: wrote %s bytes" % totalsent)

def _close(sck):
    sck.shutdown(1) # close transmit, done sending
    sck.close()

def signal(msg):
    ''' Send control msg to snmpd (if running) over UDS'''
    sck = None
    status = False
    try:
        sck = _connect()
        logger.debug("signal: connected to snmp agent")
        _send_cmd(sck, msg.encode('utf-8'))
        status = True
    except Exception as err:
        logger.error("signal: update snmpd process failed %s" % str(err))
    if sck:
        sck.close()
    return status
